@@ -1,11 +1,11 @@
 /*
-@(#)File:            esqllib.h
-@(#)Version:         1.9
-@(#)Last changed:    97/01/28
+@(#)File:            $RCSfile: esqllib.h,v $
+@(#)Version:         $Revision: 1.10 $
+@(#)Last changed:    $Date: 1997/06/02 16:24:26 $
 @(#)Purpose:         ESQL/C Library Function Prototypes
 @(#)Author:          J Leffler
 @(#)Copyright:       (C) JLSS 1992-93,1995-97
-@(#)Product:         :PRODUCT:
+@(#)Product:         $Product: DBD::Informix Version 0.56 (1997-07-08) $
 */
 
 /*TABSTOP=4*/
@@ -15,7 +15,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char esqllib_h[] = "@(#)esqllib.h	1.9 97/01/28";
+static const char esqllib_h[] = "@(#)$Id: esqllib.h,v 1.10 1997/06/02 16:24:26 johnl Exp $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
