@@ -1,7 +1,7 @@
 /*
-@(#)File:            esqlperl.h
-@(#)Version:         54.2
-@(#)Last changed:    97/05/05
+@(#)File:            $RCSfile: esqlperl.h,v $
+@(#)Version:         $Revision: 56.2 $
+@(#)Last changed:    $Date: 1997/07/13 01:09:22 $
 @(#)Purpose:         ESQL/C Utility Functions for DBD::Informix
 @(#)Author:          J Leffler
 @(#)Copyright:       (C) Jonathan Leffler 1996,1997
@@ -15,7 +15,7 @@
 
 #ifdef MAIN_PROGRAM
 #ifndef lint
-static const char esqlperl_h[] = "@(#)esqlperl.h	54.2 97/05/05";
+static const char esqlperl_h[] = "@(#)$Id: esqlperl.h,v 56.2 1997/07/13 01:09:22 johnl Exp $";
 #endif	/* lint */
 #endif	/* MAIN_PROGRAM */
 
@@ -38,13 +38,14 @@ typedef enum Boolean Boolean;
 extern char *sqltypename(int coltype, int collen, char *buffer);
 
 extern void dbd_ix_debug(int n, char *fmt, const char *arg);
+extern void dbd_ix_debug_l(int n, char *fmt, long arg);
 extern void dbd_ix_setconnection(char *conn);
 
 #if ESQLC_VERSION >= 600
 extern void dbd_ix_disconnect(char *connection);
 extern Boolean dbd_ix_connect(char *conn, char *dbase, char *user, char *pass);
 #else
-extern void dbd_ix_closedatabase(void);
+extern void dbd_ix_closedatabase(char *dbase);
 extern Boolean dbd_ix_opendatabase(char *dbase);
 #endif	/* ESQLC_VERSION >= 600 */
 
